==> aroundme_0_6_1.zip: aroundme_0_6_1/aroundme/language/1/barnraiser_01/fil_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');

//HEADER
$lang['hdr_images'] = 							"pictures";
$lang['hdr_image'] = 							"picture";
$lang['hdr_files'] = 							"files";
$lang['hdr_storage'] = 							"storage";


//HREF
$lang['href_edit'] = 							"edit";
$lang['href_open'] = 							"open";
$lang['href_add'] = 							"add";


// ERROR
$lang['err_no_files'] = 						"Sorry, no files available.";


//BODY TEXT
$lang['txt_storage_allowed'] =					"allowance";
$lang['txt_storage_total'] =					"used";
$lang['txt_kilobyte'] =							"kb";
$lang['txt_group_link'] = 						"This blog is from the group";
$lang['txt_storage_no_add'] =					"Sorry, your total storage allocation is used up. Please see the \"file uploading\" help section for more information on file allocation.";


?>

==> aroundme_0_6_8.zip: aroundme_0_6_8/aroundme/language/1/barnraiser_01/fil_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


//HEADER
$lang['hdr_images'] = 							"pictures";
$lang['hdr_image'] = 							"picture";
$lang['hdr_files'] = 							"files";
$lang['hdr_storage'] = 							"storage";


//HREF
$lang['href_edit'] = 							"edit";
$lang['href_open'] = 							"open";
$lang['href_add'] = 							"add";


// ERROR
$lang['err_no_files'] = 						"Sorry, no files available.";


//BODY TEXT
$lang['txt_storage_allowed'] =					"allowance";
$lang['txt_storage_total'] =					"used";
$lang['txt_kilobyte'] =							"kb";
$lang['txt_group_link'] = 						"This blog is from the group";
$lang['txt_storage_no_add'] =					"Sorry, your total storage allocation is used up. Please see the 'file uploading' help section for more information on file allocation.";

?>
